import { attachMacroArgs, match, processEnvironment, replaceNode, trim, walkAst } from "../libs/ast";
import * as Ast from "@unified-latex/unified-latex-types";
import { argContentsFromMacro } from "../libs/ast/arguments";
import { trimEnvironmentContents } from "../libs/macro-utils";
import { xcolorColorToHex, xcolorMacroToHex } from "@unified-latex/unified-latex-ctan/package/xcolor";
import { parseLigatures } from "@unified-latex/unified-latex-util-ligatures";
import { splitStringsIntoSingleChars } from "@unified-latex/unified-latex-util-pegjs";
import { parsePgfkeys, pgfkeysArgToObject } from "@unified-latex/unified-latex-util-pgfkeys";
import { createMacroExpander } from "./newcommand";
import { wrapPars, KATEX_SUPPORT } from "@unified-latex/unified-latex-to-hast";
import { deleteComments } from "@unified-latex/unified-latex-util-comments";
import { lints } from "@unified-latex/unified-latex-lint";
/**
 * Returns a set containing all macros in the document.
 *
 * @export
 * @param {Ast.Ast} ast
 * @returns {Map<string, Ast.Macro>}
 */
export declare function allMacros(ast: Ast.Ast): Map<string, Ast.Macro[]>;
/**
 * Returns a set containing all macros in the document.
 *
 * @export
 * @param {Ast.Ast} ast
 * @returns {Map<string, Ast.Macro>}
 */
export declare function allEnvironments(ast: Ast.Ast): Map<string, Ast.Environment[]>;
declare type IncludedPackage = {
    name: string;
    args?: Ast.Argument;
};
/**
 * Get a list of all packages directly imported into the file. This can
 * be done with `usepackage` or `RequirePackage`. Packages are returned
 * in order with the exception that all `RequirePackage` imports are before
 * all `usepackage` imports.
 *
 * Duplicates may appear if a package has been imported multiple times.
 *
 */
export declare function getIncludedPackages(ast: Ast.Ast): IncludedPackage[];
export interface NewCommandSpec {
    name: string;
    signature: string;
    substitution: Ast.Ast;
    str: string;
}
/**
 * Returns a list of all commands that have been defined in `ast` via
 * the many, many ways to define a command.
 *
 * A typical example would be
 * ```
 * \newcommand{\foo}[2]{\bar{#1}{#2}}
 * ```
 */
export declare function getNewCommands(ast: Ast.Ast): NewCommandSpec[];
/**
 * Expands macros in `ast` as specified by `macros`.
 * Each macro in `macros` should provide the substitution AST (i.e., the AST with the #1, etc.
 * in it). This function assumes that the appropriate arguments have already been attached
 * to each macro specified. If the macro doesn't have it's arguments attached, its
 * contents will be wholesale replaced with its substitution AST.
 */
export declare function expandMacros(ast: Ast.Ast, macros: {
    name: string;
    substitution: Ast.Node[];
}[]): Ast.Ast;
/**
 * Turn all ligatures into their unicode equivalent. For example,
 * `---` -> an em-dash and `\^o` to `ô`. This only applies in non-math mode,
 * since programs like katex will process math ligatures.
 */
export declare function expandUnicodeLigatures(ast: Ast.Ast): Ast.Ast;
/**
 * Generate a macro that will render like an HTML tag. E.g.,
 * ```
 * <tag>...arg[0]...</tag>
 * ```
 *
 */
export declare function tagLikeMacro({ tag, attributes, content, }: {
    tag: string;
    attributes?: Record<string, string>;
    content?: Ast.Node[];
}): Ast.Macro;
export { pgfkeysArgToObject };
/**
 * Use a heuristic to decide whether a string was parsed in math mode. The heuristic
 * looks for strings of length greater than 1 or the failure for "_" and "^" to be parsed
 * as a macro.
 */
export declare function wasParsedInMathMode(nodes: Ast.Node[]): boolean;
/**
 * Convert a latex AST to an HTML string.
 */
declare function convertToHtml(ast: Ast.Node | Ast.Node[]): string;
export { splitStringsIntoSingleChars };
declare const ast: {
    trimEnvironmentContents: typeof trimEnvironmentContents;
    trim: typeof trim;
    walkAst: typeof walkAst;
    replaceNode: typeof replaceNode;
    processEnvironment: typeof processEnvironment;
    parsePgfkeys: typeof parsePgfkeys;
    attachMacroArgs: typeof attachMacroArgs;
    deleteComments: typeof deleteComments;
};
export declare const html: {
    convertToHtml: typeof convertToHtml;
    wrapPars: typeof wrapPars;
    tagLikeMacro: typeof tagLikeMacro;
};
export declare const fixAllLints: <T extends Ast.Node | Ast.Node[]>(tree: T) => T;
/**
 * Run all lints and report the errors
 *
 * @param {(Ast.Node | Ast.Node[])} tree
 * @returns
 */
declare const lintAll: (tree: Ast.Node | Ast.Node[]) => string[];
/**
 * Given a group or a node array, look for streaming commands (e.g., `\bfseries`) and replace them
 * with the specified macro. The "arguments" of the streaming command are passed to `replacements[macroName](...)`.
 * By default, this command will split at parbreaks (since commands like `\textbf{...} do not accept parbreaks in their
 * contents).
 */
declare function replaceStreamingCommand(ast: Ast.Group | Ast.Node[], replacements: Record<string, (content: Ast.Node[], origMacro: Ast.Macro) => Ast.Node | Ast.Node[]>): Ast.Node[];
export { createMacroExpander, argContentsFromMacro, ast, match, walkAst, parseLigatures, lintAll, lints, convertToHtml, xcolorColorToHex, xcolorMacroToHex, replaceStreamingCommand, KATEX_SUPPORT, };
